"""SystemDirectoryPopulator"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.utility import _1826

_SYSTEM_DIRECTORY_POPULATOR = python_net_import(
    "SMT.MastaAPI.Utility", "SystemDirectoryPopulator"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    Self = TypeVar("Self", bound="SystemDirectoryPopulator")
    CastSelf = TypeVar(
        "CastSelf", bound="SystemDirectoryPopulator._Cast_SystemDirectoryPopulator"
    )


__docformat__ = "restructuredtext en"
__all__ = ("SystemDirectoryPopulator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SystemDirectoryPopulator:
    """Special nested class for casting SystemDirectoryPopulator to subclasses."""

    __parent__: "SystemDirectoryPopulator"

    @property
    def system_directory_populator(self: "CastSelf") -> "SystemDirectoryPopulator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SystemDirectoryPopulator(_0.APIBase):
    """SystemDirectoryPopulator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SYSTEM_DIRECTORY_POPULATOR

    class SetupFrom(Enum):
        """SetupFrom is a nested enum."""

        @classmethod
        def type_(cls) -> "Type":
            return _SYSTEM_DIRECTORY_POPULATOR.SetupFrom

        DONT_COPY = 0
        LATEST_VERSION = 1
        SPECIFIED_VERSION = 2

    def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
        raise AttributeError("Cannot set the attributes of an Enum.") from None

    def __enum_delattr(self: "Self", attr: str) -> None:
        raise AttributeError("Cannot delete the attributes of an Enum.") from None

    SetupFrom.__setattr__ = __enum_setattr
    SetupFrom.__delattr__ = __enum_delattr

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def copy_from(self: "Self") -> "SystemDirectoryPopulator.SetupFrom":
        """mastapy.utility.SystemDirectoryPopulator.SetupFrom"""
        temp = pythonnet_property_get(self.wrapped, "CopyFrom")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Utility.SystemDirectoryPopulator+SetupFrom"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.utility.SystemDirectoryPopulator.SystemDirectoryPopulator",
            "SetupFrom",
        )(value)

    @copy_from.setter
    @exception_bridge
    @enforce_parameter_types
    def copy_from(self: "Self", value: "SystemDirectoryPopulator.SetupFrom") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Utility.SystemDirectoryPopulator+SetupFrom"
        )
        pythonnet_property_set(self.wrapped, "CopyFrom", value)

    @property
    @exception_bridge
    def selected_version(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_SystemDirectory":
        """ListWithSelectedItem[mastapy.utility.SystemDirectory]"""
        temp = pythonnet_property_get(self.wrapped, "SelectedVersion")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_SystemDirectory",
        )(temp)

    @selected_version.setter
    @exception_bridge
    @enforce_parameter_types
    def selected_version(self: "Self", value: "_1826.SystemDirectory") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_SystemDirectory.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "SelectedVersion", value)

    @property
    @exception_bridge
    def current_version(self: "Self") -> "_1826.SystemDirectory":
        """mastapy.utility.SystemDirectory

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CurrentVersion")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def version_to_copy(self: "Self") -> "_1826.SystemDirectory":
        """mastapy.utility.SystemDirectory

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "VersionToCopy")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_SystemDirectoryPopulator":
        """Cast to another type.

        Returns:
            _Cast_SystemDirectoryPopulator
        """
        return _Cast_SystemDirectoryPopulator(self)



"""AbstractSystemDeflectionViewable"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.drawing import _2513

_ABSTRACT_SYSTEM_DEFLECTION_VIEWABLE = python_net_import(
    "SMT.MastaAPI.SystemModel.Drawing", "AbstractSystemDeflectionViewable"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3121,
    )
    from mastapy._private.system_model.drawing import _2504, _2506, _2520

    Self = TypeVar("Self", bound="AbstractSystemDeflectionViewable")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AbstractSystemDeflectionViewable._Cast_AbstractSystemDeflectionViewable",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractSystemDeflectionViewable",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractSystemDeflectionViewable:
    """Special nested class for casting AbstractSystemDeflectionViewable to subclasses."""

    __parent__: "AbstractSystemDeflectionViewable"

    @property
    def part_analysis_case_with_contour_viewable(
        self: "CastSelf",
    ) -> "_2513.PartAnalysisCaseWithContourViewable":
        return self.__parent__._cast(_2513.PartAnalysisCaseWithContourViewable)

    @property
    def advanced_system_deflection_viewable(
        self: "CastSelf",
    ) -> "_2504.AdvancedSystemDeflectionViewable":
        from mastapy._private.system_model.drawing import _2504

        return self.__parent__._cast(_2504.AdvancedSystemDeflectionViewable)

    @property
    def system_deflection_viewable(
        self: "CastSelf",
    ) -> "_2520.SystemDeflectionViewable":
        from mastapy._private.system_model.drawing import _2520

        return self.__parent__._cast(_2520.SystemDeflectionViewable)

    @property
    def abstract_system_deflection_viewable(
        self: "CastSelf",
    ) -> "AbstractSystemDeflectionViewable":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AbstractSystemDeflectionViewable(_2513.PartAnalysisCaseWithContourViewable):
    """AbstractSystemDeflectionViewable

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ABSTRACT_SYSTEM_DEFLECTION_VIEWABLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def contour_draw_style(self: "Self") -> "_2506.ContourDrawStyle":
        """mastapy.system_model.drawing.ContourDrawStyle

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ContourDrawStyle")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def system_deflection_draw_style(self: "Self") -> "_3121.SystemDeflectionDrawStyle":
        """mastapy.system_model.analyses_and_results.system_deflections.SystemDeflectionDrawStyle

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SystemDeflectionDrawStyle")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def fe_results(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "FEResults")

    @property
    def cast_to(self: "Self") -> "_Cast_AbstractSystemDeflectionViewable":
        """Cast to another type.

        Returns:
            _Cast_AbstractSystemDeflectionViewable
        """
        return _Cast_AbstractSystemDeflectionViewable(self)



"""MeasurementBase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item, overridable
from mastapy._private.utility.units_and_measurements import _1836

_MEASUREMENT_BASE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements", "MeasurementBase"
)

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar, Union

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.utility import _1823
    from mastapy._private.utility.units_and_measurements.measurements import (
        _1838,
        _1839,
        _1840,
        _1841,
        _1842,
        _1843,
        _1844,
        _1845,
        _1846,
        _1847,
        _1848,
        _1849,
        _1850,
        _1851,
        _1852,
        _1853,
        _1854,
        _1855,
        _1856,
        _1857,
        _1858,
        _1859,
        _1860,
        _1861,
        _1862,
        _1863,
        _1864,
        _1865,
        _1866,
        _1867,
        _1868,
        _1869,
        _1870,
        _1871,
        _1872,
        _1873,
        _1874,
        _1875,
        _1876,
        _1877,
        _1878,
        _1879,
        _1880,
        _1881,
        _1882,
        _1883,
        _1884,
        _1885,
        _1886,
        _1887,
        _1888,
        _1889,
        _1890,
        _1891,
        _1892,
        _1893,
        _1894,
        _1895,
        _1896,
        _1897,
        _1898,
        _1899,
        _1900,
        _1901,
        _1902,
        _1903,
        _1904,
        _1905,
        _1906,
        _1907,
        _1908,
        _1909,
        _1910,
        _1911,
        _1912,
        _1913,
        _1914,
        _1915,
        _1916,
        _1917,
        _1918,
        _1919,
        _1920,
        _1921,
        _1922,
        _1923,
        _1924,
        _1925,
        _1926,
        _1927,
        _1928,
        _1929,
        _1930,
        _1931,
        _1932,
        _1933,
        _1934,
        _1935,
        _1936,
        _1937,
        _1938,
        _1939,
        _1940,
        _1941,
        _1942,
        _1943,
        _1944,
        _1945,
        _1946,
        _1947,
        _1948,
        _1949,
        _1950,
        _1951,
        _1952,
        _1953,
        _1954,
        _1955,
        _1956,
        _1957,
        _1958,
        _1959,
        _1960,
        _1961,
        _1962,
        _1963,
        _1964,
        _1965,
        _1966,
        _1967,
    )

    Self = TypeVar("Self", bound="MeasurementBase")
    CastSelf = TypeVar("CastSelf", bound="MeasurementBase._Cast_MeasurementBase")


__docformat__ = "restructuredtext en"
__all__ = ("MeasurementBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MeasurementBase:
    """Special nested class for casting MeasurementBase to subclasses."""

    __parent__: "MeasurementBase"

    @property
    def acceleration(self: "CastSelf") -> "_1838.Acceleration":
        from mastapy._private.utility.units_and_measurements.measurements import _1838

        return self.__parent__._cast(_1838.Acceleration)

    @property
    def angle(self: "CastSelf") -> "_1839.Angle":
        from mastapy._private.utility.units_and_measurements.measurements import _1839

        return self.__parent__._cast(_1839.Angle)

    @property
    def angle_per_unit_temperature(self: "CastSelf") -> "_1840.AnglePerUnitTemperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1840

        return self.__parent__._cast(_1840.AnglePerUnitTemperature)

    @property
    def angle_small(self: "CastSelf") -> "_1841.AngleSmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1841

        return self.__parent__._cast(_1841.AngleSmall)

    @property
    def angle_very_small(self: "CastSelf") -> "_1842.AngleVerySmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1842

        return self.__parent__._cast(_1842.AngleVerySmall)

    @property
    def angular_acceleration(self: "CastSelf") -> "_1843.AngularAcceleration":
        from mastapy._private.utility.units_and_measurements.measurements import _1843

        return self.__parent__._cast(_1843.AngularAcceleration)

    @property
    def angular_compliance(self: "CastSelf") -> "_1844.AngularCompliance":
        from mastapy._private.utility.units_and_measurements.measurements import _1844

        return self.__parent__._cast(_1844.AngularCompliance)

    @property
    def angular_jerk(self: "CastSelf") -> "_1845.AngularJerk":
        from mastapy._private.utility.units_and_measurements.measurements import _1845

        return self.__parent__._cast(_1845.AngularJerk)

    @property
    def angular_stiffness(self: "CastSelf") -> "_1846.AngularStiffness":
        from mastapy._private.utility.units_and_measurements.measurements import _1846

        return self.__parent__._cast(_1846.AngularStiffness)

    @property
    def angular_velocity(self: "CastSelf") -> "_1847.AngularVelocity":
        from mastapy._private.utility.units_and_measurements.measurements import _1847

        return self.__parent__._cast(_1847.AngularVelocity)

    @property
    def area(self: "CastSelf") -> "_1848.Area":
        from mastapy._private.utility.units_and_measurements.measurements import _1848

        return self.__parent__._cast(_1848.Area)

    @property
    def area_small(self: "CastSelf") -> "_1849.AreaSmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1849

        return self.__parent__._cast(_1849.AreaSmall)

    @property
    def carbon_emission_factor(self: "CastSelf") -> "_1850.CarbonEmissionFactor":
        from mastapy._private.utility.units_and_measurements.measurements import _1850

        return self.__parent__._cast(_1850.CarbonEmissionFactor)

    @property
    def current_density(self: "CastSelf") -> "_1851.CurrentDensity":
        from mastapy._private.utility.units_and_measurements.measurements import _1851

        return self.__parent__._cast(_1851.CurrentDensity)

    @property
    def current_per_length(self: "CastSelf") -> "_1852.CurrentPerLength":
        from mastapy._private.utility.units_and_measurements.measurements import _1852

        return self.__parent__._cast(_1852.CurrentPerLength)

    @property
    def cycles(self: "CastSelf") -> "_1853.Cycles":
        from mastapy._private.utility.units_and_measurements.measurements import _1853

        return self.__parent__._cast(_1853.Cycles)

    @property
    def damage(self: "CastSelf") -> "_1854.Damage":
        from mastapy._private.utility.units_and_measurements.measurements import _1854

        return self.__parent__._cast(_1854.Damage)

    @property
    def damage_rate(self: "CastSelf") -> "_1855.DamageRate":
        from mastapy._private.utility.units_and_measurements.measurements import _1855

        return self.__parent__._cast(_1855.DamageRate)

    @property
    def data_size(self: "CastSelf") -> "_1856.DataSize":
        from mastapy._private.utility.units_and_measurements.measurements import _1856

        return self.__parent__._cast(_1856.DataSize)

    @property
    def decibel(self: "CastSelf") -> "_1857.Decibel":
        from mastapy._private.utility.units_and_measurements.measurements import _1857

        return self.__parent__._cast(_1857.Decibel)

    @property
    def density(self: "CastSelf") -> "_1858.Density":
        from mastapy._private.utility.units_and_measurements.measurements import _1858

        return self.__parent__._cast(_1858.Density)

    @property
    def electrical_resistance(self: "CastSelf") -> "_1859.ElectricalResistance":
        from mastapy._private.utility.units_and_measurements.measurements import _1859

        return self.__parent__._cast(_1859.ElectricalResistance)

    @property
    def electrical_resistivity(self: "CastSelf") -> "_1860.ElectricalResistivity":
        from mastapy._private.utility.units_and_measurements.measurements import _1860

        return self.__parent__._cast(_1860.ElectricalResistivity)

    @property
    def electric_current(self: "CastSelf") -> "_1861.ElectricCurrent":
        from mastapy._private.utility.units_and_measurements.measurements import _1861

        return self.__parent__._cast(_1861.ElectricCurrent)

    @property
    def energy(self: "CastSelf") -> "_1862.Energy":
        from mastapy._private.utility.units_and_measurements.measurements import _1862

        return self.__parent__._cast(_1862.Energy)

    @property
    def energy_per_unit_area(self: "CastSelf") -> "_1863.EnergyPerUnitArea":
        from mastapy._private.utility.units_and_measurements.measurements import _1863

        return self.__parent__._cast(_1863.EnergyPerUnitArea)

    @property
    def energy_per_unit_area_small(self: "CastSelf") -> "_1864.EnergyPerUnitAreaSmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1864

        return self.__parent__._cast(_1864.EnergyPerUnitAreaSmall)

    @property
    def energy_small(self: "CastSelf") -> "_1865.EnergySmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1865

        return self.__parent__._cast(_1865.EnergySmall)

    @property
    def enum(self: "CastSelf") -> "_1866.Enum":
        from mastapy._private.utility.units_and_measurements.measurements import _1866

        return self.__parent__._cast(_1866.Enum)

    @property
    def flow_rate(self: "CastSelf") -> "_1867.FlowRate":
        from mastapy._private.utility.units_and_measurements.measurements import _1867

        return self.__parent__._cast(_1867.FlowRate)

    @property
    def flow_resistance(self: "CastSelf") -> "_1868.FlowResistance":
        from mastapy._private.utility.units_and_measurements.measurements import _1868

        return self.__parent__._cast(_1868.FlowResistance)

    @property
    def force(self: "CastSelf") -> "_1869.Force":
        from mastapy._private.utility.units_and_measurements.measurements import _1869

        return self.__parent__._cast(_1869.Force)

    @property
    def force_per_unit_length(self: "CastSelf") -> "_1870.ForcePerUnitLength":
        from mastapy._private.utility.units_and_measurements.measurements import _1870

        return self.__parent__._cast(_1870.ForcePerUnitLength)

    @property
    def force_per_unit_pressure(self: "CastSelf") -> "_1871.ForcePerUnitPressure":
        from mastapy._private.utility.units_and_measurements.measurements import _1871

        return self.__parent__._cast(_1871.ForcePerUnitPressure)

    @property
    def force_per_unit_temperature(self: "CastSelf") -> "_1872.ForcePerUnitTemperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1872

        return self.__parent__._cast(_1872.ForcePerUnitTemperature)

    @property
    def fraction_measurement_base(self: "CastSelf") -> "_1873.FractionMeasurementBase":
        from mastapy._private.utility.units_and_measurements.measurements import _1873

        return self.__parent__._cast(_1873.FractionMeasurementBase)

    @property
    def fraction_per_temperature(self: "CastSelf") -> "_1874.FractionPerTemperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1874

        return self.__parent__._cast(_1874.FractionPerTemperature)

    @property
    def frequency(self: "CastSelf") -> "_1875.Frequency":
        from mastapy._private.utility.units_and_measurements.measurements import _1875

        return self.__parent__._cast(_1875.Frequency)

    @property
    def fuel_consumption_engine(self: "CastSelf") -> "_1876.FuelConsumptionEngine":
        from mastapy._private.utility.units_and_measurements.measurements import _1876

        return self.__parent__._cast(_1876.FuelConsumptionEngine)

    @property
    def fuel_efficiency_vehicle(self: "CastSelf") -> "_1877.FuelEfficiencyVehicle":
        from mastapy._private.utility.units_and_measurements.measurements import _1877

        return self.__parent__._cast(_1877.FuelEfficiencyVehicle)

    @property
    def gradient(self: "CastSelf") -> "_1878.Gradient":
        from mastapy._private.utility.units_and_measurements.measurements import _1878

        return self.__parent__._cast(_1878.Gradient)

    @property
    def heat_conductivity(self: "CastSelf") -> "_1879.HeatConductivity":
        from mastapy._private.utility.units_and_measurements.measurements import _1879

        return self.__parent__._cast(_1879.HeatConductivity)

    @property
    def heat_transfer(self: "CastSelf") -> "_1880.HeatTransfer":
        from mastapy._private.utility.units_and_measurements.measurements import _1880

        return self.__parent__._cast(_1880.HeatTransfer)

    @property
    def heat_transfer_coefficient_for_plastic_gear_tooth(
        self: "CastSelf",
    ) -> "_1881.HeatTransferCoefficientForPlasticGearTooth":
        from mastapy._private.utility.units_and_measurements.measurements import _1881

        return self.__parent__._cast(_1881.HeatTransferCoefficientForPlasticGearTooth)

    @property
    def heat_transfer_resistance(self: "CastSelf") -> "_1882.HeatTransferResistance":
        from mastapy._private.utility.units_and_measurements.measurements import _1882

        return self.__parent__._cast(_1882.HeatTransferResistance)

    @property
    def impulse(self: "CastSelf") -> "_1883.Impulse":
        from mastapy._private.utility.units_and_measurements.measurements import _1883

        return self.__parent__._cast(_1883.Impulse)

    @property
    def index(self: "CastSelf") -> "_1884.Index":
        from mastapy._private.utility.units_and_measurements.measurements import _1884

        return self.__parent__._cast(_1884.Index)

    @property
    def inductance(self: "CastSelf") -> "_1885.Inductance":
        from mastapy._private.utility.units_and_measurements.measurements import _1885

        return self.__parent__._cast(_1885.Inductance)

    @property
    def integer(self: "CastSelf") -> "_1886.Integer":
        from mastapy._private.utility.units_and_measurements.measurements import _1886

        return self.__parent__._cast(_1886.Integer)

    @property
    def inverse_short_length(self: "CastSelf") -> "_1887.InverseShortLength":
        from mastapy._private.utility.units_and_measurements.measurements import _1887

        return self.__parent__._cast(_1887.InverseShortLength)

    @property
    def inverse_short_time(self: "CastSelf") -> "_1888.InverseShortTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1888

        return self.__parent__._cast(_1888.InverseShortTime)

    @property
    def jerk(self: "CastSelf") -> "_1889.Jerk":
        from mastapy._private.utility.units_and_measurements.measurements import _1889

        return self.__parent__._cast(_1889.Jerk)

    @property
    def kinematic_viscosity(self: "CastSelf") -> "_1890.KinematicViscosity":
        from mastapy._private.utility.units_and_measurements.measurements import _1890

        return self.__parent__._cast(_1890.KinematicViscosity)

    @property
    def length_long(self: "CastSelf") -> "_1891.LengthLong":
        from mastapy._private.utility.units_and_measurements.measurements import _1891

        return self.__parent__._cast(_1891.LengthLong)

    @property
    def length_medium(self: "CastSelf") -> "_1892.LengthMedium":
        from mastapy._private.utility.units_and_measurements.measurements import _1892

        return self.__parent__._cast(_1892.LengthMedium)

    @property
    def length_per_unit_temperature(
        self: "CastSelf",
    ) -> "_1893.LengthPerUnitTemperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1893

        return self.__parent__._cast(_1893.LengthPerUnitTemperature)

    @property
    def length_short(self: "CastSelf") -> "_1894.LengthShort":
        from mastapy._private.utility.units_and_measurements.measurements import _1894

        return self.__parent__._cast(_1894.LengthShort)

    @property
    def length_to_the_fourth(self: "CastSelf") -> "_1895.LengthToTheFourth":
        from mastapy._private.utility.units_and_measurements.measurements import _1895

        return self.__parent__._cast(_1895.LengthToTheFourth)

    @property
    def length_very_long(self: "CastSelf") -> "_1896.LengthVeryLong":
        from mastapy._private.utility.units_and_measurements.measurements import _1896

        return self.__parent__._cast(_1896.LengthVeryLong)

    @property
    def length_very_short(self: "CastSelf") -> "_1897.LengthVeryShort":
        from mastapy._private.utility.units_and_measurements.measurements import _1897

        return self.__parent__._cast(_1897.LengthVeryShort)

    @property
    def length_very_short_per_length_short(
        self: "CastSelf",
    ) -> "_1898.LengthVeryShortPerLengthShort":
        from mastapy._private.utility.units_and_measurements.measurements import _1898

        return self.__parent__._cast(_1898.LengthVeryShortPerLengthShort)

    @property
    def linear_angular_damping(self: "CastSelf") -> "_1899.LinearAngularDamping":
        from mastapy._private.utility.units_and_measurements.measurements import _1899

        return self.__parent__._cast(_1899.LinearAngularDamping)

    @property
    def linear_angular_stiffness_cross_term(
        self: "CastSelf",
    ) -> "_1900.LinearAngularStiffnessCrossTerm":
        from mastapy._private.utility.units_and_measurements.measurements import _1900

        return self.__parent__._cast(_1900.LinearAngularStiffnessCrossTerm)

    @property
    def linear_damping(self: "CastSelf") -> "_1901.LinearDamping":
        from mastapy._private.utility.units_and_measurements.measurements import _1901

        return self.__parent__._cast(_1901.LinearDamping)

    @property
    def linear_flexibility(self: "CastSelf") -> "_1902.LinearFlexibility":
        from mastapy._private.utility.units_and_measurements.measurements import _1902

        return self.__parent__._cast(_1902.LinearFlexibility)

    @property
    def linear_stiffness(self: "CastSelf") -> "_1903.LinearStiffness":
        from mastapy._private.utility.units_and_measurements.measurements import _1903

        return self.__parent__._cast(_1903.LinearStiffness)

    @property
    def magnetic_field_strength(self: "CastSelf") -> "_1904.MagneticFieldStrength":
        from mastapy._private.utility.units_and_measurements.measurements import _1904

        return self.__parent__._cast(_1904.MagneticFieldStrength)

    @property
    def magnetic_flux(self: "CastSelf") -> "_1905.MagneticFlux":
        from mastapy._private.utility.units_and_measurements.measurements import _1905

        return self.__parent__._cast(_1905.MagneticFlux)

    @property
    def magnetic_flux_density(self: "CastSelf") -> "_1906.MagneticFluxDensity":
        from mastapy._private.utility.units_and_measurements.measurements import _1906

        return self.__parent__._cast(_1906.MagneticFluxDensity)

    @property
    def magnetic_vector_potential(self: "CastSelf") -> "_1907.MagneticVectorPotential":
        from mastapy._private.utility.units_and_measurements.measurements import _1907

        return self.__parent__._cast(_1907.MagneticVectorPotential)

    @property
    def magnetomotive_force(self: "CastSelf") -> "_1908.MagnetomotiveForce":
        from mastapy._private.utility.units_and_measurements.measurements import _1908

        return self.__parent__._cast(_1908.MagnetomotiveForce)

    @property
    def mass(self: "CastSelf") -> "_1909.Mass":
        from mastapy._private.utility.units_and_measurements.measurements import _1909

        return self.__parent__._cast(_1909.Mass)

    @property
    def mass_per_unit_length(self: "CastSelf") -> "_1910.MassPerUnitLength":
        from mastapy._private.utility.units_and_measurements.measurements import _1910

        return self.__parent__._cast(_1910.MassPerUnitLength)

    @property
    def mass_per_unit_time(self: "CastSelf") -> "_1911.MassPerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1911

        return self.__parent__._cast(_1911.MassPerUnitTime)

    @property
    def moment_of_inertia(self: "CastSelf") -> "_1912.MomentOfInertia":
        from mastapy._private.utility.units_and_measurements.measurements import _1912

        return self.__parent__._cast(_1912.MomentOfInertia)

    @property
    def moment_of_inertia_per_unit_length(
        self: "CastSelf",
    ) -> "_1913.MomentOfInertiaPerUnitLength":
        from mastapy._private.utility.units_and_measurements.measurements import _1913

        return self.__parent__._cast(_1913.MomentOfInertiaPerUnitLength)

    @property
    def moment_per_unit_pressure(self: "CastSelf") -> "_1914.MomentPerUnitPressure":
        from mastapy._private.utility.units_and_measurements.measurements import _1914

        return self.__parent__._cast(_1914.MomentPerUnitPressure)

    @property
    def number(self: "CastSelf") -> "_1915.Number":
        from mastapy._private.utility.units_and_measurements.measurements import _1915

        return self.__parent__._cast(_1915.Number)

    @property
    def percentage(self: "CastSelf") -> "_1916.Percentage":
        from mastapy._private.utility.units_and_measurements.measurements import _1916

        return self.__parent__._cast(_1916.Percentage)

    @property
    def power(self: "CastSelf") -> "_1917.Power":
        from mastapy._private.utility.units_and_measurements.measurements import _1917

        return self.__parent__._cast(_1917.Power)

    @property
    def power_per_small_area(self: "CastSelf") -> "_1918.PowerPerSmallArea":
        from mastapy._private.utility.units_and_measurements.measurements import _1918

        return self.__parent__._cast(_1918.PowerPerSmallArea)

    @property
    def power_per_unit_time(self: "CastSelf") -> "_1919.PowerPerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1919

        return self.__parent__._cast(_1919.PowerPerUnitTime)

    @property
    def power_small(self: "CastSelf") -> "_1920.PowerSmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1920

        return self.__parent__._cast(_1920.PowerSmall)

    @property
    def power_small_per_area(self: "CastSelf") -> "_1921.PowerSmallPerArea":
        from mastapy._private.utility.units_and_measurements.measurements import _1921

        return self.__parent__._cast(_1921.PowerSmallPerArea)

    @property
    def power_small_per_mass(self: "CastSelf") -> "_1922.PowerSmallPerMass":
        from mastapy._private.utility.units_and_measurements.measurements import _1922

        return self.__parent__._cast(_1922.PowerSmallPerMass)

    @property
    def power_small_per_unit_area_per_unit_time(
        self: "CastSelf",
    ) -> "_1923.PowerSmallPerUnitAreaPerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1923

        return self.__parent__._cast(_1923.PowerSmallPerUnitAreaPerUnitTime)

    @property
    def power_small_per_unit_time(self: "CastSelf") -> "_1924.PowerSmallPerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1924

        return self.__parent__._cast(_1924.PowerSmallPerUnitTime)

    @property
    def power_small_per_volume(self: "CastSelf") -> "_1925.PowerSmallPerVolume":
        from mastapy._private.utility.units_and_measurements.measurements import _1925

        return self.__parent__._cast(_1925.PowerSmallPerVolume)

    @property
    def pressure(self: "CastSelf") -> "_1926.Pressure":
        from mastapy._private.utility.units_and_measurements.measurements import _1926

        return self.__parent__._cast(_1926.Pressure)

    @property
    def pressure_per_unit_time(self: "CastSelf") -> "_1927.PressurePerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1927

        return self.__parent__._cast(_1927.PressurePerUnitTime)

    @property
    def pressure_small(self: "CastSelf") -> "_1928.PressureSmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1928

        return self.__parent__._cast(_1928.PressureSmall)

    @property
    def pressure_velocity_product(self: "CastSelf") -> "_1929.PressureVelocityProduct":
        from mastapy._private.utility.units_and_measurements.measurements import _1929

        return self.__parent__._cast(_1929.PressureVelocityProduct)

    @property
    def pressure_viscosity_coefficient(
        self: "CastSelf",
    ) -> "_1930.PressureViscosityCoefficient":
        from mastapy._private.utility.units_and_measurements.measurements import _1930

        return self.__parent__._cast(_1930.PressureViscosityCoefficient)

    @property
    def price(self: "CastSelf") -> "_1931.Price":
        from mastapy._private.utility.units_and_measurements.measurements import _1931

        return self.__parent__._cast(_1931.Price)

    @property
    def price_per_unit_mass(self: "CastSelf") -> "_1932.PricePerUnitMass":
        from mastapy._private.utility.units_and_measurements.measurements import _1932

        return self.__parent__._cast(_1932.PricePerUnitMass)

    @property
    def quadratic_angular_damping(self: "CastSelf") -> "_1933.QuadraticAngularDamping":
        from mastapy._private.utility.units_and_measurements.measurements import _1933

        return self.__parent__._cast(_1933.QuadraticAngularDamping)

    @property
    def quadratic_drag(self: "CastSelf") -> "_1934.QuadraticDrag":
        from mastapy._private.utility.units_and_measurements.measurements import _1934

        return self.__parent__._cast(_1934.QuadraticDrag)

    @property
    def rescaled_measurement(self: "CastSelf") -> "_1935.RescaledMeasurement":
        from mastapy._private.utility.units_and_measurements.measurements import _1935

        return self.__parent__._cast(_1935.RescaledMeasurement)

    @property
    def rotatum(self: "CastSelf") -> "_1936.Rotatum":
        from mastapy._private.utility.units_and_measurements.measurements import _1936

        return self.__parent__._cast(_1936.Rotatum)

    @property
    def safety_factor(self: "CastSelf") -> "_1937.SafetyFactor":
        from mastapy._private.utility.units_and_measurements.measurements import _1937

        return self.__parent__._cast(_1937.SafetyFactor)

    @property
    def specific_acoustic_impedance(
        self: "CastSelf",
    ) -> "_1938.SpecificAcousticImpedance":
        from mastapy._private.utility.units_and_measurements.measurements import _1938

        return self.__parent__._cast(_1938.SpecificAcousticImpedance)

    @property
    def specific_heat(self: "CastSelf") -> "_1939.SpecificHeat":
        from mastapy._private.utility.units_and_measurements.measurements import _1939

        return self.__parent__._cast(_1939.SpecificHeat)

    @property
    def square_root_of_unit_force_per_unit_area(
        self: "CastSelf",
    ) -> "_1940.SquareRootOfUnitForcePerUnitArea":
        from mastapy._private.utility.units_and_measurements.measurements import _1940

        return self.__parent__._cast(_1940.SquareRootOfUnitForcePerUnitArea)

    @property
    def stiffness_per_unit_face_width(
        self: "CastSelf",
    ) -> "_1941.StiffnessPerUnitFaceWidth":
        from mastapy._private.utility.units_and_measurements.measurements import _1941

        return self.__parent__._cast(_1941.StiffnessPerUnitFaceWidth)

    @property
    def stress(self: "CastSelf") -> "_1942.Stress":
        from mastapy._private.utility.units_and_measurements.measurements import _1942

        return self.__parent__._cast(_1942.Stress)

    @property
    def temperature(self: "CastSelf") -> "_1943.Temperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1943

        return self.__parent__._cast(_1943.Temperature)

    @property
    def temperature_difference(self: "CastSelf") -> "_1944.TemperatureDifference":
        from mastapy._private.utility.units_and_measurements.measurements import _1944

        return self.__parent__._cast(_1944.TemperatureDifference)

    @property
    def temperature_per_unit_time(self: "CastSelf") -> "_1945.TemperaturePerUnitTime":
        from mastapy._private.utility.units_and_measurements.measurements import _1945

        return self.__parent__._cast(_1945.TemperaturePerUnitTime)

    @property
    def text(self: "CastSelf") -> "_1946.Text":
        from mastapy._private.utility.units_and_measurements.measurements import _1946

        return self.__parent__._cast(_1946.Text)

    @property
    def thermal_contact_coefficient(
        self: "CastSelf",
    ) -> "_1947.ThermalContactCoefficient":
        from mastapy._private.utility.units_and_measurements.measurements import _1947

        return self.__parent__._cast(_1947.ThermalContactCoefficient)

    @property
    def thermal_expansion_coefficient(
        self: "CastSelf",
    ) -> "_1948.ThermalExpansionCoefficient":
        from mastapy._private.utility.units_and_measurements.measurements import _1948

        return self.__parent__._cast(_1948.ThermalExpansionCoefficient)

    @property
    def thermal_resistance(self: "CastSelf") -> "_1949.ThermalResistance":
        from mastapy._private.utility.units_and_measurements.measurements import _1949

        return self.__parent__._cast(_1949.ThermalResistance)

    @property
    def thermo_elastic_factor(self: "CastSelf") -> "_1950.ThermoElasticFactor":
        from mastapy._private.utility.units_and_measurements.measurements import _1950

        return self.__parent__._cast(_1950.ThermoElasticFactor)

    @property
    def time(self: "CastSelf") -> "_1951.Time":
        from mastapy._private.utility.units_and_measurements.measurements import _1951

        return self.__parent__._cast(_1951.Time)

    @property
    def time_short(self: "CastSelf") -> "_1952.TimeShort":
        from mastapy._private.utility.units_and_measurements.measurements import _1952

        return self.__parent__._cast(_1952.TimeShort)

    @property
    def time_very_short(self: "CastSelf") -> "_1953.TimeVeryShort":
        from mastapy._private.utility.units_and_measurements.measurements import _1953

        return self.__parent__._cast(_1953.TimeVeryShort)

    @property
    def torque(self: "CastSelf") -> "_1954.Torque":
        from mastapy._private.utility.units_and_measurements.measurements import _1954

        return self.__parent__._cast(_1954.Torque)

    @property
    def torque_converter_inverse_k(self: "CastSelf") -> "_1955.TorqueConverterInverseK":
        from mastapy._private.utility.units_and_measurements.measurements import _1955

        return self.__parent__._cast(_1955.TorqueConverterInverseK)

    @property
    def torque_converter_k(self: "CastSelf") -> "_1956.TorqueConverterK":
        from mastapy._private.utility.units_and_measurements.measurements import _1956

        return self.__parent__._cast(_1956.TorqueConverterK)

    @property
    def torque_per_current(self: "CastSelf") -> "_1957.TorquePerCurrent":
        from mastapy._private.utility.units_and_measurements.measurements import _1957

        return self.__parent__._cast(_1957.TorquePerCurrent)

    @property
    def torque_per_square_root_of_power(
        self: "CastSelf",
    ) -> "_1958.TorquePerSquareRootOfPower":
        from mastapy._private.utility.units_and_measurements.measurements import _1958

        return self.__parent__._cast(_1958.TorquePerSquareRootOfPower)

    @property
    def torque_per_unit_temperature(
        self: "CastSelf",
    ) -> "_1959.TorquePerUnitTemperature":
        from mastapy._private.utility.units_and_measurements.measurements import _1959

        return self.__parent__._cast(_1959.TorquePerUnitTemperature)

    @property
    def velocity(self: "CastSelf") -> "_1960.Velocity":
        from mastapy._private.utility.units_and_measurements.measurements import _1960

        return self.__parent__._cast(_1960.Velocity)

    @property
    def velocity_small(self: "CastSelf") -> "_1961.VelocitySmall":
        from mastapy._private.utility.units_and_measurements.measurements import _1961

        return self.__parent__._cast(_1961.VelocitySmall)

    @property
    def viscosity(self: "CastSelf") -> "_1962.Viscosity":
        from mastapy._private.utility.units_and_measurements.measurements import _1962

        return self.__parent__._cast(_1962.Viscosity)

    @property
    def voltage(self: "CastSelf") -> "_1963.Voltage":
        from mastapy._private.utility.units_and_measurements.measurements import _1963

        return self.__parent__._cast(_1963.Voltage)

    @property
    def voltage_per_angular_velocity(
        self: "CastSelf",
    ) -> "_1964.VoltagePerAngularVelocity":
        from mastapy._private.utility.units_and_measurements.measurements import _1964

        return self.__parent__._cast(_1964.VoltagePerAngularVelocity)

    @property
    def volume(self: "CastSelf") -> "_1965.Volume":
        from mastapy._private.utility.units_and_measurements.measurements import _1965

        return self.__parent__._cast(_1965.Volume)

    @property
    def wear_coefficient(self: "CastSelf") -> "_1966.WearCoefficient":
        from mastapy._private.utility.units_and_measurements.measurements import _1966

        return self.__parent__._cast(_1966.WearCoefficient)

    @property
    def yank(self: "CastSelf") -> "_1967.Yank":
        from mastapy._private.utility.units_and_measurements.measurements import _1967

        return self.__parent__._cast(_1967.Yank)

    @property
    def measurement_base(self: "CastSelf") -> "MeasurementBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MeasurementBase(_0.APIBase):
    """MeasurementBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MEASUREMENT_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def absolute_tolerance(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "AbsoluteTolerance")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @absolute_tolerance.setter
    @exception_bridge
    @enforce_parameter_types
    def absolute_tolerance(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "AbsoluteTolerance", value)

    @property
    @exception_bridge
    def default_unit(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_Unit":
        """ListWithSelectedItem[mastapy.utility.units_and_measurements.Unit]"""
        temp = pythonnet_property_get(self.wrapped, "DefaultUnit")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Unit",
        )(temp)

    @default_unit.setter
    @exception_bridge
    @enforce_parameter_types
    def default_unit(self: "Self", value: "_1836.Unit") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "DefaultUnit", value)

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def percentage_tolerance(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "PercentageTolerance")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @percentage_tolerance.setter
    @exception_bridge
    @enforce_parameter_types
    def percentage_tolerance(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "PercentageTolerance", value)

    @property
    @exception_bridge
    def rounding_digits(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "RoundingDigits")

        if temp is None:
            return 0

        return temp

    @rounding_digits.setter
    @exception_bridge
    @enforce_parameter_types
    def rounding_digits(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "RoundingDigits", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def rounding_method(self: "Self") -> "_1823.RoundingMethods":
        """mastapy.utility.RoundingMethods"""
        temp = pythonnet_property_get(self.wrapped, "RoundingMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Utility.RoundingMethods")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.utility._1823", "RoundingMethods"
        )(value)

    @rounding_method.setter
    @exception_bridge
    @enforce_parameter_types
    def rounding_method(self: "Self", value: "_1823.RoundingMethods") -> None:
        value = conversion.mp_to_pn_enum(value, "SMT.MastaAPI.Utility.RoundingMethods")
        pythonnet_property_set(self.wrapped, "RoundingMethod", value)

    @property
    @exception_bridge
    def current_unit(self: "Self") -> "_1836.Unit":
        """mastapy.utility.units_and_measurements.Unit

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CurrentUnit")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def available_units(self: "Self") -> "List[_1836.Unit]":
        """List[mastapy.utility.units_and_measurements.Unit]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AvailableUnits")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_MeasurementBase":
        """Cast to another type.

        Returns:
            _Cast_MeasurementBase
        """
        return _Cast_MeasurementBase(self)



"""NonLinearBearing"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.bearings.bearing_designs import _2378

_NON_LINEAR_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns", "NonLinearBearing"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_designs import _2379
    from mastapy._private.bearings.bearing_designs.concept import _2446, _2447, _2448
    from mastapy._private.bearings.bearing_designs.fluid_film import (
        _2436,
        _2438,
        _2440,
        _2442,
        _2443,
        _2444,
    )
    from mastapy._private.bearings.bearing_designs.rolling import (
        _2383,
        _2384,
        _2385,
        _2386,
        _2387,
        _2388,
        _2390,
        _2396,
        _2397,
        _2398,
        _2402,
        _2407,
        _2408,
        _2409,
        _2410,
        _2413,
        _2415,
        _2418,
        _2419,
        _2420,
        _2421,
        _2422,
        _2423,
    )

    Self = TypeVar("Self", bound="NonLinearBearing")
    CastSelf = TypeVar("CastSelf", bound="NonLinearBearing._Cast_NonLinearBearing")


__docformat__ = "restructuredtext en"
__all__ = ("NonLinearBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_NonLinearBearing:
    """Special nested class for casting NonLinearBearing to subclasses."""

    __parent__: "NonLinearBearing"

    @property
    def bearing_design(self: "CastSelf") -> "_2378.BearingDesign":
        return self.__parent__._cast(_2378.BearingDesign)

    @property
    def detailed_bearing(self: "CastSelf") -> "_2379.DetailedBearing":
        from mastapy._private.bearings.bearing_designs import _2379

        return self.__parent__._cast(_2379.DetailedBearing)

    @property
    def angular_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2383.AngularContactBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2383

        return self.__parent__._cast(_2383.AngularContactBallBearing)

    @property
    def angular_contact_thrust_ball_bearing(
        self: "CastSelf",
    ) -> "_2384.AngularContactThrustBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2384

        return self.__parent__._cast(_2384.AngularContactThrustBallBearing)

    @property
    def asymmetric_spherical_roller_bearing(
        self: "CastSelf",
    ) -> "_2385.AsymmetricSphericalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2385

        return self.__parent__._cast(_2385.AsymmetricSphericalRollerBearing)

    @property
    def axial_thrust_cylindrical_roller_bearing(
        self: "CastSelf",
    ) -> "_2386.AxialThrustCylindricalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2386

        return self.__parent__._cast(_2386.AxialThrustCylindricalRollerBearing)

    @property
    def axial_thrust_needle_roller_bearing(
        self: "CastSelf",
    ) -> "_2387.AxialThrustNeedleRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2387

        return self.__parent__._cast(_2387.AxialThrustNeedleRollerBearing)

    @property
    def ball_bearing(self: "CastSelf") -> "_2388.BallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2388

        return self.__parent__._cast(_2388.BallBearing)

    @property
    def barrel_roller_bearing(self: "CastSelf") -> "_2390.BarrelRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2390

        return self.__parent__._cast(_2390.BarrelRollerBearing)

    @property
    def crossed_roller_bearing(self: "CastSelf") -> "_2396.CrossedRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2396

        return self.__parent__._cast(_2396.CrossedRollerBearing)

    @property
    def cylindrical_roller_bearing(
        self: "CastSelf",
    ) -> "_2397.CylindricalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2397

        return self.__parent__._cast(_2397.CylindricalRollerBearing)

    @property
    def deep_groove_ball_bearing(self: "CastSelf") -> "_2398.DeepGrooveBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2398

        return self.__parent__._cast(_2398.DeepGrooveBallBearing)

    @property
    def four_point_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2402.FourPointContactBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2402

        return self.__parent__._cast(_2402.FourPointContactBallBearing)

    @property
    def multi_point_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2407.MultiPointContactBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2407

        return self.__parent__._cast(_2407.MultiPointContactBallBearing)

    @property
    def needle_roller_bearing(self: "CastSelf") -> "_2408.NeedleRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2408

        return self.__parent__._cast(_2408.NeedleRollerBearing)

    @property
    def non_barrel_roller_bearing(self: "CastSelf") -> "_2409.NonBarrelRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2409

        return self.__parent__._cast(_2409.NonBarrelRollerBearing)

    @property
    def roller_bearing(self: "CastSelf") -> "_2410.RollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2410

        return self.__parent__._cast(_2410.RollerBearing)

    @property
    def rolling_bearing(self: "CastSelf") -> "_2413.RollingBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2413

        return self.__parent__._cast(_2413.RollingBearing)

    @property
    def self_aligning_ball_bearing(self: "CastSelf") -> "_2415.SelfAligningBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2415

        return self.__parent__._cast(_2415.SelfAligningBallBearing)

    @property
    def spherical_roller_bearing(self: "CastSelf") -> "_2418.SphericalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2418

        return self.__parent__._cast(_2418.SphericalRollerBearing)

    @property
    def spherical_roller_thrust_bearing(
        self: "CastSelf",
    ) -> "_2419.SphericalRollerThrustBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2419

        return self.__parent__._cast(_2419.SphericalRollerThrustBearing)

    @property
    def taper_roller_bearing(self: "CastSelf") -> "_2420.TaperRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2420

        return self.__parent__._cast(_2420.TaperRollerBearing)

    @property
    def three_point_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2421.ThreePointContactBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2421

        return self.__parent__._cast(_2421.ThreePointContactBallBearing)

    @property
    def thrust_ball_bearing(self: "CastSelf") -> "_2422.ThrustBallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2422

        return self.__parent__._cast(_2422.ThrustBallBearing)

    @property
    def toroidal_roller_bearing(self: "CastSelf") -> "_2423.ToroidalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2423

        return self.__parent__._cast(_2423.ToroidalRollerBearing)

    @property
    def pad_fluid_film_bearing(self: "CastSelf") -> "_2436.PadFluidFilmBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2436

        return self.__parent__._cast(_2436.PadFluidFilmBearing)

    @property
    def plain_grease_filled_journal_bearing(
        self: "CastSelf",
    ) -> "_2438.PlainGreaseFilledJournalBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2438

        return self.__parent__._cast(_2438.PlainGreaseFilledJournalBearing)

    @property
    def plain_journal_bearing(self: "CastSelf") -> "_2440.PlainJournalBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2440

        return self.__parent__._cast(_2440.PlainJournalBearing)

    @property
    def plain_oil_fed_journal_bearing(
        self: "CastSelf",
    ) -> "_2442.PlainOilFedJournalBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2442

        return self.__parent__._cast(_2442.PlainOilFedJournalBearing)

    @property
    def tilting_pad_journal_bearing(
        self: "CastSelf",
    ) -> "_2443.TiltingPadJournalBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2443

        return self.__parent__._cast(_2443.TiltingPadJournalBearing)

    @property
    def tilting_pad_thrust_bearing(self: "CastSelf") -> "_2444.TiltingPadThrustBearing":
        from mastapy._private.bearings.bearing_designs.fluid_film import _2444

        return self.__parent__._cast(_2444.TiltingPadThrustBearing)

    @property
    def concept_axial_clearance_bearing(
        self: "CastSelf",
    ) -> "_2446.ConceptAxialClearanceBearing":
        from mastapy._private.bearings.bearing_designs.concept import _2446

        return self.__parent__._cast(_2446.ConceptAxialClearanceBearing)

    @property
    def concept_clearance_bearing(self: "CastSelf") -> "_2447.ConceptClearanceBearing":
        from mastapy._private.bearings.bearing_designs.concept import _2447

        return self.__parent__._cast(_2447.ConceptClearanceBearing)

    @property
    def concept_radial_clearance_bearing(
        self: "CastSelf",
    ) -> "_2448.ConceptRadialClearanceBearing":
        from mastapy._private.bearings.bearing_designs.concept import _2448

        return self.__parent__._cast(_2448.ConceptRadialClearanceBearing)

    @property
    def non_linear_bearing(self: "CastSelf") -> "NonLinearBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class NonLinearBearing(_2378.BearingDesign):
    """NonLinearBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _NON_LINEAR_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_NonLinearBearing":
        """Cast to another type.

        Returns:
            _Cast_NonLinearBearing
        """
        return _Cast_NonLinearBearing(self)



"""ConicalSetMicroGeometryConfigBase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import enum_with_selected_value
from mastapy._private.gears.analysis import _1377
from mastapy._private.gears.ltca import _953

_CONICAL_SET_MICRO_GEOMETRY_CONFIG_BASE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Bevel", "ConicalSetMicroGeometryConfigBase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears import _431
    from mastapy._private.gears.analysis import _1363, _1372
    from mastapy._private.gears.manufacturing.bevel import _917, _918

    Self = TypeVar("Self", bound="ConicalSetMicroGeometryConfigBase")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalSetMicroGeometryConfigBase._Cast_ConicalSetMicroGeometryConfigBase",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalSetMicroGeometryConfigBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalSetMicroGeometryConfigBase:
    """Special nested class for casting ConicalSetMicroGeometryConfigBase to subclasses."""

    __parent__: "ConicalSetMicroGeometryConfigBase"

    @property
    def gear_set_implementation_detail(
        self: "CastSelf",
    ) -> "_1377.GearSetImplementationDetail":
        return self.__parent__._cast(_1377.GearSetImplementationDetail)

    @property
    def gear_set_design_analysis(self: "CastSelf") -> "_1372.GearSetDesignAnalysis":
        from mastapy._private.gears.analysis import _1372

        return self.__parent__._cast(_1372.GearSetDesignAnalysis)

    @property
    def abstract_gear_set_analysis(self: "CastSelf") -> "_1363.AbstractGearSetAnalysis":
        from mastapy._private.gears.analysis import _1363

        return self.__parent__._cast(_1363.AbstractGearSetAnalysis)

    @property
    def conical_set_manufacturing_config(
        self: "CastSelf",
    ) -> "_917.ConicalSetManufacturingConfig":
        from mastapy._private.gears.manufacturing.bevel import _917

        return self.__parent__._cast(_917.ConicalSetManufacturingConfig)

    @property
    def conical_set_micro_geometry_config(
        self: "CastSelf",
    ) -> "_918.ConicalSetMicroGeometryConfig":
        from mastapy._private.gears.manufacturing.bevel import _918

        return self.__parent__._cast(_918.ConicalSetMicroGeometryConfig)

    @property
    def conical_set_micro_geometry_config_base(
        self: "CastSelf",
    ) -> "ConicalSetMicroGeometryConfigBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConicalSetMicroGeometryConfigBase(_1377.GearSetImplementationDetail):
    """ConicalSetMicroGeometryConfigBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_SET_MICRO_GEOMETRY_CONFIG_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def compound_layer_thickness(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "CompoundLayerThickness")

        if temp is None:
            return 0.0

        return temp

    @compound_layer_thickness.setter
    @exception_bridge
    @enforce_parameter_types
    def compound_layer_thickness(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "CompoundLayerThickness",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def contact_chart_results_type(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ContactResultType":
        """EnumWithSelectedValue[mastapy.gears.ltca.ContactResultType]"""
        temp = pythonnet_property_get(self.wrapped, "ContactChartResultsType")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_ContactResultType.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @contact_chart_results_type.setter
    @exception_bridge
    @enforce_parameter_types
    def contact_chart_results_type(
        self: "Self", value: "_953.ContactResultType"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ContactResultType.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "ContactChartResultsType", value)

    @property
    @exception_bridge
    def deflection_from_bending_option(
        self: "Self",
    ) -> "_431.DeflectionFromBendingOption":
        """mastapy.gears.DeflectionFromBendingOption"""
        temp = pythonnet_property_get(self.wrapped, "DeflectionFromBendingOption")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.DeflectionFromBendingOption"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears._431", "DeflectionFromBendingOption"
        )(value)

    @deflection_from_bending_option.setter
    @exception_bridge
    @enforce_parameter_types
    def deflection_from_bending_option(
        self: "Self", value: "_431.DeflectionFromBendingOption"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.DeflectionFromBendingOption"
        )
        pythonnet_property_set(self.wrapped, "DeflectionFromBendingOption", value)

    @property
    @exception_bridge
    def file_location_for_contact_chart(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "FileLocationForContactChart")

        if temp is None:
            return ""

        return temp

    @file_location_for_contact_chart.setter
    @exception_bridge
    @enforce_parameter_types
    def file_location_for_contact_chart(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "FileLocationForContactChart",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def number_of_columns_for_grid(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfColumnsForGrid")

        if temp is None:
            return 0

        return temp

    @number_of_columns_for_grid.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_columns_for_grid(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfColumnsForGrid",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_points_for_interpolated_surface_u(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfPointsForInterpolatedSurfaceU"
        )

        if temp is None:
            return 0

        return temp

    @number_of_points_for_interpolated_surface_u.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_points_for_interpolated_surface_u(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfPointsForInterpolatedSurfaceU",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_points_for_interpolated_surface_v(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfPointsForInterpolatedSurfaceV"
        )

        if temp is None:
            return 0

        return temp

    @number_of_points_for_interpolated_surface_v.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_points_for_interpolated_surface_v(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfPointsForInterpolatedSurfaceV",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_rows_for_fillet_grid(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfRowsForFilletGrid")

        if temp is None:
            return 0

        return temp

    @number_of_rows_for_fillet_grid.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_rows_for_fillet_grid(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfRowsForFilletGrid",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_rows_for_flank_grid(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfRowsForFlankGrid")

        if temp is None:
            return 0

        return temp

    @number_of_rows_for_flank_grid.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_rows_for_flank_grid(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfRowsForFlankGrid",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def single_tooth_stiffness(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "SingleToothStiffness")

        if temp is None:
            return 0.0

        return temp

    @single_tooth_stiffness.setter
    @exception_bridge
    @enforce_parameter_types
    def single_tooth_stiffness(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SingleToothStiffness",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def write_contact_chart_to_file_after_solve(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "WriteContactChartToFileAfterSolve")

        if temp is None:
            return False

        return temp

    @write_contact_chart_to_file_after_solve.setter
    @exception_bridge
    @enforce_parameter_types
    def write_contact_chart_to_file_after_solve(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "WriteContactChartToFileAfterSolve",
            bool(value) if value is not None else False,
        )

    @exception_bridge
    def select_file_save_path(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "SelectFileSavePath")

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalSetMicroGeometryConfigBase":
        """Cast to another type.

        Returns:
            _Cast_ConicalSetMicroGeometryConfigBase
        """
        return _Cast_ConicalSetMicroGeometryConfigBase(self)



"""IndependentMASTACreatedConstrainedNodesWithSelectionComponents"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import constructor, utility

_INDEPENDENT_MASTA_CREATED_CONSTRAINED_NODES_WITH_SELECTION_COMPONENTS = (
    python_net_import(
        "SMT.MastaAPI.SystemModel.FE",
        "IndependentMASTACreatedConstrainedNodesWithSelectionComponents",
    )
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.fe import _2660

    Self = TypeVar(
        "Self", bound="IndependentMASTACreatedConstrainedNodesWithSelectionComponents"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="IndependentMASTACreatedConstrainedNodesWithSelectionComponents._Cast_IndependentMASTACreatedConstrainedNodesWithSelectionComponents",
    )


__docformat__ = "restructuredtext en"
__all__ = ("IndependentMASTACreatedConstrainedNodesWithSelectionComponents",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_IndependentMASTACreatedConstrainedNodesWithSelectionComponents:
    """Special nested class for casting IndependentMASTACreatedConstrainedNodesWithSelectionComponents to subclasses."""

    __parent__: "IndependentMASTACreatedConstrainedNodesWithSelectionComponents"

    @property
    def independent_masta_created_constrained_nodes_with_selection_components(
        self: "CastSelf",
    ) -> "IndependentMASTACreatedConstrainedNodesWithSelectionComponents":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class IndependentMASTACreatedConstrainedNodesWithSelectionComponents(_0.APIBase):
    """IndependentMASTACreatedConstrainedNodesWithSelectionComponents

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _INDEPENDENT_MASTA_CREATED_CONSTRAINED_NODES_WITH_SELECTION_COMPONENTS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def node(self: "Self") -> "_2660.IndependentMASTACreatedConstrainedNodes":
        """mastapy.system_model.fe.IndependentMASTACreatedConstrainedNodes

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Node")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def select(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "Select")

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_IndependentMASTACreatedConstrainedNodesWithSelectionComponents":
        """Cast to another type.

        Returns:
            _Cast_IndependentMASTACreatedConstrainedNodesWithSelectionComponents
        """
        return _Cast_IndependentMASTACreatedConstrainedNodesWithSelectionComponents(
            self
        )



"""ShaftSectionSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.nodal_analysis.nodal_entities import _139

_SHAFT_SECTION_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections",
    "ShaftSectionSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.nodal_entities import _159, _161
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3097,
    )

    Self = TypeVar("Self", bound="ShaftSectionSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ShaftSectionSystemDeflection._Cast_ShaftSectionSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ShaftSectionSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftSectionSystemDeflection:
    """Special nested class for casting ShaftSectionSystemDeflection to subclasses."""

    __parent__: "ShaftSectionSystemDeflection"

    @property
    def bar_base(self: "CastSelf") -> "_139.BarBase":
        return self.__parent__._cast(_139.BarBase)

    @property
    def nodal_component(self: "CastSelf") -> "_159.NodalComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _159

        return self.__parent__._cast(_159.NodalComponent)

    @property
    def nodal_entity(self: "CastSelf") -> "_161.NodalEntity":
        from mastapy._private.nodal_analysis.nodal_entities import _161

        return self.__parent__._cast(_161.NodalEntity)

    @property
    def shaft_section_system_deflection(
        self: "CastSelf",
    ) -> "ShaftSectionSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ShaftSectionSystemDeflection(_139.BarBase):
    """ShaftSectionSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SHAFT_SECTION_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def left_end(self: "Self") -> "_3097.ShaftSectionEndResultsSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.ShaftSectionEndResultsSystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeftEnd")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def right_end(self: "Self") -> "_3097.ShaftSectionEndResultsSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.ShaftSectionEndResultsSystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RightEnd")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ShaftSectionSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_ShaftSectionSystemDeflection
        """
        return _Cast_ShaftSectionSystemDeflection(self)



"""SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
    _5318,
)

_SPECIALISED_ASSEMBLY_COMPOUND_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness.Compound",
    "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _5287,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
        _5324,
        _5328,
        _5331,
        _5336,
        _5338,
        _5339,
        _5344,
        _5349,
        _5352,
        _5355,
        _5359,
        _5361,
        _5367,
        _5373,
        _5375,
        _5378,
        _5382,
        _5386,
        _5389,
        _5392,
        _5395,
        _5399,
        _5400,
        _5404,
        _5411,
        _5421,
        _5422,
        _5427,
        _5430,
        _5433,
        _5437,
        _5445,
        _5448,
    )

    Self = TypeVar("Self", bound="SpecialisedAssemblyCompoundModalAnalysisAtAStiffness")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SpecialisedAssemblyCompoundModalAnalysisAtAStiffness._Cast_SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpecialisedAssemblyCompoundModalAnalysisAtAStiffness:
    """Special nested class for casting SpecialisedAssemblyCompoundModalAnalysisAtAStiffness to subclasses."""

    __parent__: "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"

    @property
    def abstract_assembly_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5318.AbstractAssemblyCompoundModalAnalysisAtAStiffness":
        return self.__parent__._cast(
            _5318.AbstractAssemblyCompoundModalAnalysisAtAStiffness
        )

    @property
    def part_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5399.PartCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5399,
        )

        return self.__parent__._cast(_5399.PartCompoundModalAnalysisAtAStiffness)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5324.AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5324,
        )

        return self.__parent__._cast(
            _5324.AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def belt_drive_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5328.BeltDriveCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5328,
        )

        return self.__parent__._cast(_5328.BeltDriveCompoundModalAnalysisAtAStiffness)

    @property
    def bevel_differential_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5331.BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5331,
        )

        return self.__parent__._cast(
            _5331.BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def bevel_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5336.BevelGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5336,
        )

        return self.__parent__._cast(
            _5336.BevelGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def bolted_joint_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5338.BoltedJointCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5338,
        )

        return self.__parent__._cast(_5338.BoltedJointCompoundModalAnalysisAtAStiffness)

    @property
    def clutch_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5339.ClutchCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5339,
        )

        return self.__parent__._cast(_5339.ClutchCompoundModalAnalysisAtAStiffness)

    @property
    def concept_coupling_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5344.ConceptCouplingCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5344,
        )

        return self.__parent__._cast(
            _5344.ConceptCouplingCompoundModalAnalysisAtAStiffness
        )

    @property
    def concept_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5349.ConceptGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5349,
        )

        return self.__parent__._cast(
            _5349.ConceptGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def conical_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5352.ConicalGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5352,
        )

        return self.__parent__._cast(
            _5352.ConicalGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def coupling_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5355.CouplingCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5355,
        )

        return self.__parent__._cast(_5355.CouplingCompoundModalAnalysisAtAStiffness)

    @property
    def cvt_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5359.CVTCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5359,
        )

        return self.__parent__._cast(_5359.CVTCompoundModalAnalysisAtAStiffness)

    @property
    def cycloidal_assembly_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5361.CycloidalAssemblyCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5361,
        )

        return self.__parent__._cast(
            _5361.CycloidalAssemblyCompoundModalAnalysisAtAStiffness
        )

    @property
    def cylindrical_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5367.CylindricalGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5367,
        )

        return self.__parent__._cast(
            _5367.CylindricalGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def face_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5373.FaceGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5373,
        )

        return self.__parent__._cast(_5373.FaceGearSetCompoundModalAnalysisAtAStiffness)

    @property
    def flexible_pin_assembly_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5375.FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5375,
        )

        return self.__parent__._cast(
            _5375.FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness
        )

    @property
    def gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5378.GearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5378,
        )

        return self.__parent__._cast(_5378.GearSetCompoundModalAnalysisAtAStiffness)

    @property
    def hypoid_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5382.HypoidGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5382,
        )

        return self.__parent__._cast(
            _5382.HypoidGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> (
        "_5386.KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness"
    ):
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5386,
        )

        return self.__parent__._cast(
            _5386.KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5389.KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5389,
        )

        return self.__parent__._cast(
            _5389.KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5392.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5392,
        )

        return self.__parent__._cast(
            _5392.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def microphone_array_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5395.MicrophoneArrayCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5395,
        )

        return self.__parent__._cast(
            _5395.MicrophoneArrayCompoundModalAnalysisAtAStiffness
        )

    @property
    def part_to_part_shear_coupling_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5400.PartToPartShearCouplingCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5400,
        )

        return self.__parent__._cast(
            _5400.PartToPartShearCouplingCompoundModalAnalysisAtAStiffness
        )

    @property
    def planetary_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5404.PlanetaryGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5404,
        )

        return self.__parent__._cast(
            _5404.PlanetaryGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def rolling_ring_assembly_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5411.RollingRingAssemblyCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5411,
        )

        return self.__parent__._cast(
            _5411.RollingRingAssemblyCompoundModalAnalysisAtAStiffness
        )

    @property
    def spiral_bevel_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5421.SpiralBevelGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5421,
        )

        return self.__parent__._cast(
            _5421.SpiralBevelGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def spring_damper_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5422.SpringDamperCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5422,
        )

        return self.__parent__._cast(
            _5422.SpringDamperCompoundModalAnalysisAtAStiffness
        )

    @property
    def straight_bevel_diff_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5427.StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5427,
        )

        return self.__parent__._cast(
            _5427.StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def straight_bevel_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5430.StraightBevelGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5430,
        )

        return self.__parent__._cast(
            _5430.StraightBevelGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def synchroniser_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5433.SynchroniserCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5433,
        )

        return self.__parent__._cast(
            _5433.SynchroniserCompoundModalAnalysisAtAStiffness
        )

    @property
    def torque_converter_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5437.TorqueConverterCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5437,
        )

        return self.__parent__._cast(
            _5437.TorqueConverterCompoundModalAnalysisAtAStiffness
        )

    @property
    def worm_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5445.WormGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5445,
        )

        return self.__parent__._cast(_5445.WormGearSetCompoundModalAnalysisAtAStiffness)

    @property
    def zerol_bevel_gear_set_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5448.ZerolBevelGearSetCompoundModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import (
            _5448,
        )

        return self.__parent__._cast(
            _5448.ZerolBevelGearSetCompoundModalAnalysisAtAStiffness
        )

    @property
    def specialised_assembly_compound_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SpecialisedAssemblyCompoundModalAnalysisAtAStiffness(
    _5318.AbstractAssemblyCompoundModalAnalysisAtAStiffness
):
    """SpecialisedAssemblyCompoundModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _SPECIALISED_ASSEMBLY_COMPOUND_MODAL_ANALYSIS_AT_A_STIFFNESS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_5287.SpecialisedAssemblyModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.SpecialisedAssemblyModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5287.SpecialisedAssemblyModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.SpecialisedAssemblyModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_SpecialisedAssemblyCompoundModalAnalysisAtAStiffness":
        """Cast to another type.

        Returns:
            _Cast_SpecialisedAssemblyCompoundModalAnalysisAtAStiffness
        """
        return _Cast_SpecialisedAssemblyCompoundModalAnalysisAtAStiffness(self)



"""ResultOptionsFor3DVector"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_RESULT_OPTIONS_FOR_3D_VECTOR = python_net_import(
    "SMT.MastaAPI.MathUtility", "ResultOptionsFor3DVector"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ResultOptionsFor3DVector")
    CastSelf = TypeVar(
        "CastSelf", bound="ResultOptionsFor3DVector._Cast_ResultOptionsFor3DVector"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ResultOptionsFor3DVector",)


class ResultOptionsFor3DVector(Enum):
    """ResultOptionsFor3DVector

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _RESULT_OPTIONS_FOR_3D_VECTOR

    X = 0
    Y = 1
    Z = 2
    MAGNITUDE_XY = 3
    MAGNITUDE = 4
    RADIAL_XY = 5
    TANGENTIAL_XY = 6


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ResultOptionsFor3DVector.__setattr__ = __enum_setattr
ResultOptionsFor3DVector.__delattr__ = __enum_delattr



"""RollerRibDetail"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, utility
from mastapy._private._internal.implicit import overridable

_ROLLER_RIB_DETAIL = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Rolling", "RollerRibDetail"
)

if TYPE_CHECKING:
    from typing import Any, Tuple, Type, TypeVar, Union

    Self = TypeVar("Self", bound="RollerRibDetail")
    CastSelf = TypeVar("CastSelf", bound="RollerRibDetail._Cast_RollerRibDetail")


__docformat__ = "restructuredtext en"
__all__ = ("RollerRibDetail",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RollerRibDetail:
    """Special nested class for casting RollerRibDetail to subclasses."""

    __parent__: "RollerRibDetail"

    @property
    def roller_rib_detail(self: "CastSelf") -> "RollerRibDetail":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RollerRibDetail(_0.APIBase):
    """RollerRibDetail

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROLLER_RIB_DETAIL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def chamfer(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "Chamfer")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @chamfer.setter
    @exception_bridge
    @enforce_parameter_types
    def chamfer(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "Chamfer", value)

    @property
    @exception_bridge
    def diameter(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "Diameter")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def diameter(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "Diameter", value)

    @property
    @exception_bridge
    def height_above_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HeightAboveRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def layback_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "LaybackAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @layback_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def layback_angle(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "LaybackAngle", value)

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def nominal_contact_height_above_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NominalContactHeightAboveRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def present(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "Present")

        if temp is None:
            return False

        return temp

    @present.setter
    @exception_bridge
    @enforce_parameter_types
    def present(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "Present", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def undercut_axial_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UndercutAxialAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @undercut_axial_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def undercut_axial_angle(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UndercutAxialAngle", value)

    @property
    @exception_bridge
    def undercut_axial_start_offset(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UndercutAxialStartOffset")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @undercut_axial_start_offset.setter
    @exception_bridge
    @enforce_parameter_types
    def undercut_axial_start_offset(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UndercutAxialStartOffset", value)

    @property
    @exception_bridge
    def undercut_radial_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UndercutRadialAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @undercut_radial_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def undercut_radial_angle(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UndercutRadialAngle", value)

    @property
    @exception_bridge
    def undercut_radial_start_offset(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UndercutRadialStartOffset")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @undercut_radial_start_offset.setter
    @exception_bridge
    @enforce_parameter_types
    def undercut_radial_start_offset(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UndercutRadialStartOffset", value)

    @property
    @exception_bridge
    def undercut_radius(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UndercutRadius")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @undercut_radius.setter
    @exception_bridge
    @enforce_parameter_types
    def undercut_radius(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UndercutRadius", value)

    @property
    def cast_to(self: "Self") -> "_Cast_RollerRibDetail":
        """Cast to another type.

        Returns:
            _Cast_RollerRibDetail
        """
        return _Cast_RollerRibDetail(self)



"""SpiralBevelGearSetDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.gears.gear_designs.bevel import _1328

_SPIRAL_BEVEL_GEAR_SET_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.SpiralBevel", "SpiralBevelGearSetDesign"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs import _1074, _1076
    from mastapy._private.gears.gear_designs.agma_gleason_conical import _1341
    from mastapy._private.gears.gear_designs.conical import _1302
    from mastapy._private.gears.gear_designs.spiral_bevel import _1095, _1096

    Self = TypeVar("Self", bound="SpiralBevelGearSetDesign")
    CastSelf = TypeVar(
        "CastSelf", bound="SpiralBevelGearSetDesign._Cast_SpiralBevelGearSetDesign"
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpiralBevelGearSetDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpiralBevelGearSetDesign:
    """Special nested class for casting SpiralBevelGearSetDesign to subclasses."""

    __parent__: "SpiralBevelGearSetDesign"

    @property
    def bevel_gear_set_design(self: "CastSelf") -> "_1328.BevelGearSetDesign":
        return self.__parent__._cast(_1328.BevelGearSetDesign)

    @property
    def agma_gleason_conical_gear_set_design(
        self: "CastSelf",
    ) -> "_1341.AGMAGleasonConicalGearSetDesign":
        from mastapy._private.gears.gear_designs.agma_gleason_conical import _1341

        return self.__parent__._cast(_1341.AGMAGleasonConicalGearSetDesign)

    @property
    def conical_gear_set_design(self: "CastSelf") -> "_1302.ConicalGearSetDesign":
        from mastapy._private.gears.gear_designs.conical import _1302

        return self.__parent__._cast(_1302.ConicalGearSetDesign)

    @property
    def gear_set_design(self: "CastSelf") -> "_1076.GearSetDesign":
        from mastapy._private.gears.gear_designs import _1076

        return self.__parent__._cast(_1076.GearSetDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_1074.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _1074

        return self.__parent__._cast(_1074.GearDesignComponent)

    @property
    def spiral_bevel_gear_set_design(self: "CastSelf") -> "SpiralBevelGearSetDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SpiralBevelGearSetDesign(_1328.BevelGearSetDesign):
    """SpiralBevelGearSetDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPIRAL_BEVEL_GEAR_SET_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def minimum_number_of_teeth_for_recommended_tooth_proportions(
        self: "Self",
    ) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MinimumNumberOfTeethForRecommendedToothProportions"
        )

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def spiral_bevel_gears(self: "Self") -> "List[_1095.SpiralBevelGearDesign]":
        """List[mastapy.gears.gear_designs.spiral_bevel.SpiralBevelGearDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SpiralBevelGears")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def spiral_bevel_meshes(self: "Self") -> "List[_1096.SpiralBevelGearMeshDesign]":
        """List[mastapy.gears.gear_designs.spiral_bevel.SpiralBevelGearMeshDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SpiralBevelMeshes")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_SpiralBevelGearSetDesign":
        """Cast to another type.

        Returns:
            _Cast_SpiralBevelGearSetDesign
        """
        return _Cast_SpiralBevelGearSetDesign(self)
